@@ -57,3 +57,13 @@ class ExampleClass:
             ac gravida.
 
         """
+
+    def method(self, attr1, attr2):
+        """Test method docstring.
+
+        :param str attr1: attr1 description.
+        :param str attr2: attr2 description.
+
+        :returns: This returns something.
+
+        """
